Documentation
¶
Index ¶
Constants ¶
const MaxPoolSize = 64 * 1024 // 64KB
MaxPoolSize defines the largest buffer size we'll keep in the pool.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Decoder ¶
type Decoder struct {
// contains filtered or unexported fields
}
func NewDecoder ¶
type Encoder ¶
type Encoder struct {
// contains filtered or unexported fields
}
func NewEncoder ¶
func (*Encoder) Encode ¶
Encode encodes the given proto message and writes it to the underlying writer.
func (*Encoder) EncodeSize ¶
EncodeSize returns the size in bytes that the encoded message will take
Click to show internal directories.
Click to hide internal directories.